@@ -3,9 +3,12 @@
  * @brief Header file for DecklinkReader class
  * @author Jonathan Thomas <jonathan@openshot.org>
  *
- * @section LICENSE
+ * @ref License
+ */
+
+/* LICENSE
  *
- * Copyright (c) 2008-2014 OpenShot Studios, LLC
+ * Copyright (c) 2008-2019 OpenShot Studios, LLC
  * <http://www.openshotstudios.com/>. This file is part of
  * OpenShot Library (libopenshot), an open-source project dedicated to
  * delivering high quality video editing and animation solutions to the
@@ -47,8 +50,6 @@
 #include "Frame.h"
 #include "DecklinkInput.h"
 
-using namespace std;
-
 namespace openshot
 {
 
@@ -56,7 +57,7 @@ namespace openshot
 	 * @brief This class uses the Blackmagic Decklink libraries, to open video streams on Blackmagic devices.
 	 *
 	 * This requires special hardware manufactured by <a href="http://www.blackmagicdesign.com/products">Blackmagic Designs</a>.
-	 * Once the device is aquired and connected, this reader returns openshot::Frame objects containing the image and audio data.
+	 * Once the device is acquired and connected, this reader returns openshot::Frame objects containing the image and audio data.
 	 */
 	class DecklinkReader : public ReaderBase
 	{
@@ -93,7 +94,7 @@ namespace openshot
 
 		/// Constructor for DecklinkReader.  This automatically opens the device and loads
 		/// the first second of video, or it throws one of the following exceptions.
-		DecklinkReader(int device, int video_mode, int pixel_format, int channels, int sample_depth) throw(DecklinkError);
+		DecklinkReader(int device, int video_mode, int pixel_format, int channels, int sample_depth);
 		~DecklinkReader(); /// Destructor
 
 		/// Close the device and video stream
@@ -107,23 +108,23 @@ namespace openshot
 		///
 		/// @returns The requested frame (containing the image)
 		/// @param requested_frame The frame number that is requested.
-		std::shared_ptr<Frame> GetFrame(long int requested_frame) throw(ReaderClosed);
+		std::shared_ptr<Frame> GetFrame(int64_t requested_frame);
 		unsigned long GetCurrentFrameNumber();
 
 		/// Determine if reader is open or closed
 		bool IsOpen() { return is_open; };
 
 		/// Return the type name of the class
-		string Name() { return "DecklinkReader"; };
+		std::string Name() { return "DecklinkReader"; };
 
 		/// Get and Set JSON methods
-		string Json(); ///< Generate JSON string of this object
-		void SetJson(string value) throw(InvalidJSON); ///< Load JSON string into this object
-		Json::Value JsonValue(); ///< Generate Json::JsonValue for this object
-		void SetJsonValue(Json::Value root) throw(InvalidFile); ///< Load Json::JsonValue into this object
+		std::string Json() const override; ///< Generate JSON string of this object
+		void SetJson(const std::string value); ///< Load JSON string into this object
+		Json::Value JsonValue() const; ///< Generate Json::Value for this object
+		void SetJsonValue(const Json::Value root); ///< Load Json::Value into this object
 
 		/// Open device and video stream - which is called by the constructor automatically
-		void Open() throw(DecklinkError);
+		void Open();
 	};
 
 }
